@@ -1,4 +1,7 @@
 import pilas
+# Permite que este ejemplo funcion incluso si no has instalado pilas.
+import sys
+sys.path.insert(0, "..")
 
 pilas.iniciar()
 ejes = pilas.actores.Ejes()
