@@ -41,14 +41,62 @@ __all__ = ['actores', 'iniciar', 'terminar', 'ejecutar', 'interpolar', 'avisar']
 
 import utils
 import motores
-import elements
+import simbolos
+import os
+import sys
+import time
+import estudiante
+import baseactor
+import colores
+import imagenes
+import sonidos
+import actores
+import fps
+from interpolaciones import Lineal
+import dispatch
+import eventos
+import habilidades
+import ventana
+import comportamientos
+import escenas
+import fondos
+from control import Control
+from camara import Camara
+import copy
+import pilas.utils
+from mundo import Mundo
+from colisiones import Colisiones
+import random
+import ejemplos
+import red
 
+import atajos
+import fisica
+import grupo
+import lienzo
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+    
+    
 # Carga el modulo de autocompletado si esta
 # en sesion interactiva.
 if utils.esta_en_sesion_interactiva():
     utils.cargar_autocompletado()
 
-def iniciar(ancho=640, alto=480, titulo='Pilas', usar_motor='pysfml', modo='detectar'):
+def iniciar(ancho=640, alto=480, titulo='Pilas', usar_motor='pysfml', modo='detectar', rendimiento=60, economico=True):
     """Inicia el motor y abre la ventana principal del videojuego.
     
     Esta funcion se ejecuta al principio de cualquier juego, porque
@@ -60,7 +108,7 @@ def iniciar(ancho=640, alto=480, titulo='Pilas', usar_motor='pysfml', modo='dete
         pilas.iniciar()
 
     aunque también puedes indicarle puntualmente el valor de algún
-    argumento:
+    argumento::
 
         pilas.iniciar(titulo='titulo de mi juego')
 
@@ -83,39 +131,6 @@ def iniciar(ancho=640, alto=480, titulo='Pilas', usar_motor='pysfml', modo='dete
 
     motor = motores_disponibles[usar_motor]()
 
-    import simbolos
-    import os
-    import sys
-    import time
-
-    import baseactor
-    import colores
-    import imagenes
-    import sonidos
-    import actores
-    import fps
-    from interpolaciones import Lineal
-    import dispatch
-    import eventos
-    import habilidades
-    import ventana
-    import comportamientos
-    import escenas
-    import fondos
-    from control import Control
-    from camara import Camara
-    import copy
-    import pilas.utils
-    from mundo import Mundo
-    from colisiones import Colisiones
-    import random
-    import ejemplos
-    import red
-    import motores
-    import atajos
-    import fisica
-    import grupo
-
     pilas.colisiones = Colisiones()
 
     # Cuando inicia en modo interactivo se asegura
@@ -123,32 +138,31 @@ def iniciar(ancho=640, alto=480, titulo='Pilas', usar_motor='pysfml', modo='dete
     # tiene el contexto opengl.
     if modo == 'detectar':
         if utils.esta_en_sesion_interactiva():
-            iniciar_y_cargar_en_segundo_plano(ancho, alto, titulo + " [Modo Interactivo]")
+            iniciar_y_cargar_en_segundo_plano(ancho, alto, titulo + " [Modo Interactivo]", rendimiento, economico)
         else:
-            mundo = pilas.mundo.Mundo(ancho, alto, titulo)
+            mundo = pilas.mundo.Mundo(ancho, alto, titulo, rendimiento, economico)
             escenas.Normal()
     elif modo == 'interactivo':
-        iniciar_y_cargar_en_segundo_plano(ancho, alto, titulo + " [Modo Interactivo]")
+        iniciar_y_cargar_en_segundo_plano(ancho, alto, titulo + " [Modo Interactivo]", rendimiento, economico)
     else:
         raise Exception("Lo siento, el modo indicado es invalido, solo se admite 'interactivo' y 'detectar'")
 
 
-def iniciar_y_cargar_en_segundo_plano(ancho, alto, titulo):
+def iniciar_y_cargar_en_segundo_plano(ancho, alto, titulo, fps, economico):
     "Ejecuta el bucle de pilas en segundo plano."
     import threading
     global gb
 
-    bg = threading.Thread(target=iniciar_y_ejecutar, args=(ancho, alto, titulo))
+    bg = threading.Thread(target=__iniciar_y_ejecutar, args=(ancho, alto, titulo, fps, economico))
     bg.start()
 
 def reiniciar():
     actores.utils.eliminar_a_todos()
 
-def iniciar_y_ejecutar(ancho, alto, titulo, ignorar_errores=False):
-    from mundo import Mundo
+def __iniciar_y_ejecutar(ancho, alto, titulo, fps, economico, ignorar_errores=False):
     global mundo
 
-    mundo = Mundo(ancho, alto, titulo)
+    mundo = Mundo(ancho, alto, titulo, fps, economico)
     escenas.Normal()
     ejecutar(ignorar_errores)
 
@@ -227,9 +241,10 @@ def avisar(mensaje):
         anterior_texto.eliminar()
 
     texto = actores.Texto(mensaje)
+    texto.centro = ("centro", "centro")
     texto.magnitud = 22
-    texto.izquierda = -310
-    texto.abajo = -230
+    texto.izquierda = -320
+    texto.abajo = -220
     anterior_texto = texto
 
 def ver(objeto):
@@ -269,3 +284,13 @@ def obtener_motores_disponibles():
         pass
 
     return (motores_disponibles, sistema_recomendado)
+
+
+def ejecutar_cada(segundos, funcion):
+    """Ejecuta una funcion con la frecuencia que indica el argumento segundos.
+    
+    La funcion ejecutada tiene que retornar True para volver a
+    ejecutarse, si retorna False se elimina el temporizador y la funcion
+    no se vuelve a ejecutar.
+    """
+    pilas.mundo.agregar_tarea(segundos, funcion)
