@@ -11,24 +11,24 @@ import math
 
 import pilas
 import utils
+from actor import Actor
 
 todos = []
 
-Actor = pilas.motor.Actor
-
 from mono import *
 from ejes import *
 from animado import Animado
 from animacion import Animacion
-
 from explosion import Explosion
 from bomba import Bomba
 from pingu import Pingu
 from banana import Banana
 from texto import Texto
+from temporizador import Temporizador
 from moneda import Moneda
 from pizarra import Pizarra
 from pelota import Pelota
+from puntaje import Puntaje
 from estrella import Estrella
 from caja import Caja
 from nave import Nave
@@ -41,3 +41,4 @@ from tortuga import Tortuga
 from mapa import Mapa
 from martian import Martian
 from boton import Boton
+from entradadetexto import EntradaDeTexto
