@@ -32,25 +32,23 @@ class Lapiz(object):
 
     x = property(get_x, set_x)
     y = property(get_y, set_y)
+
+class PizarraAbstracta():
     
-
-class Pizarra(Actor):
-    """Representa una superficie de dibujo inicialmente transparente.
-
-    Puedes pintar sobre esta pizarra usando métodos que simulan
-    un lapiz, que se puede mover sobre una superficie.
-    """
-
-    def __init__(self, x=0, y=0):
-        Actor.__init__(self, x=x, y=y)
-        self.canvas = pilas.motor.Canvas()
+    def __init__(self, ancho=640, alto=480):
+        self.canvas = pilas.motor.obtener_canvas(ancho, alto)
         self.lapiz = Lapiz()
-        self.actualizar_imagen()
+
         self.levantar_lapiz()
         self.mover_lapiz(0, 0)
-        self.definir_centro(320, 240)
-        self.habilitar_actualizacion_automatica()
 
+        self.actualizar_imagen()
+        self.habilitar_actualizacion_automatica()        
+        self.centro = ("medio", "medio")
+                
+    def asignar(self, actor):
+        actor.imagen = self.canvas.image
+        
     def habilitar_actualizacion_automatica(self):
         self.actualiza_automaticamente = True
         self.actualizar_imagen()
@@ -58,25 +56,26 @@ class Pizarra(Actor):
     def deshabilitar_actualizacion_automatica(self):
         self.actualiza_automaticamente = False
 
+    def actualizar_imagen(self):
+        "Se encarga de actualizar la vista de la pizarra."
+        self.canvas.actualizar()
+        
     def levantar_lapiz(self):
         self.lapiz_bajo = False
 
     def bajar_lapiz(self):
         self.lapiz_bajo = True
 
-    def actualizar_imagen(self):
-        "Se encarga de actualizar la vista de la pizarra."
-        self.canvas.actualizar()
-        self.definir_imagen(self.canvas.image)
-
-    def pintar_punto(self, x, y):
+    def pintar_punto(self, x, y, radio, color):
         y = 240 - y
         x += 320
-        self.canvas.context.arc(x, y, 10, 0, 2*3.1415)
+        self.definir_color(color)
+        self.canvas.context.arc(x, y, radio, 0, 2*3.1415)
         self.canvas.context.fill()
         if self.actualiza_automaticamente:
             self.actualizar_imagen()
 
+        
     def mover_lapiz(self, x, y):
         if self.lapiz_bajo:
             self.canvas.context.move_to(self.lapiz.x, self.lapiz.y)
@@ -93,7 +92,8 @@ class Pizarra(Actor):
         self.lapiz.x, self.lapiz.y = x, y
         
     def definir_color(self, color):
-        r, g, b = color.obtener_componentes()
+        b, g, r, a = color.obtener_componentes()
+        
         self.canvas.context.set_source_rgb(r/255.0, g/255.0, b/255.0)
 
     def pintar_imagen(self, imagen, x=0, y=0):
@@ -102,19 +102,22 @@ class Pizarra(Actor):
         Las coordenadas de pantalla tienen su origen en la esquina
         superior izquierda, no en el centro de la ventana.
         """
-        imagen = pilas.motor.generar_imagen_cairo(imagen)
+        
+        if not isinstance(imagen, cairo.ImageSurface):
+            imagen = pilas.motor.obtener_imagen_cairo(imagen)
+            
         w = imagen.get_width()
         h = imagen.get_height()
-        self._pintar_parte_de_imagen(imagen, 0, 0, w, h, x, y)
+        self.pintar_parte_de_imagen(imagen, 0, 0, w, h, x, y)
 
     def pintar_grilla(self, grilla, x=0, y=0):
-        imagen = pilas.motor.generar_imagen_cairo(grilla.image)
+        imagen = pilas.motor.obtener_imagen_cairo(grilla.image)
         w = grilla.cuadro_ancho
         h = grilla.cuadro_alto
         dx = grilla.cuadro * grilla.cuadro_ancho
-        self._pintar_parte_de_imagen(imagen, dx, 0, w, h, x, y)
+        self.pintar_parte_de_imagen(imagen, dx, 0, w, h, x, y)
 
-    def _pintar_parte_de_imagen(self, imagen_cairo, origen_x, origen_y, ancho, alto, x, y):
+    def pintar_parte_de_imagen(self, imagen_cairo, origen_x, origen_y, ancho, alto, x, y):
         """Dibuja una porcion de imagen sobre la pizarra pero usando coordenadas de pantalla.
 
         Los argumentos ``origen_x`` y ``origen_y`` indican la parte
@@ -141,19 +144,42 @@ class Pizarra(Actor):
 
         self.canvas.context.rectangle(0, 0, w, h)
         self.canvas.context.fill()
+        
         if self.actualiza_automaticamente:
             self.actualizar_imagen()
 
-    def escribir(self, texto, x=0, y=0, tamano=32, fuente="Arial"):
+    def escribir(self, texto, x=0, y=0, tamano=32, fuente="sans"):
         "Pinta una cadena de texto con el color actual del trazo."
         self.canvas.context.move_to(x, y)
         self.canvas.context.set_font_size(tamano)
         self.canvas.context.select_font_face(fuente)
-        self.canvas.context.text_path(texto)
+        self.canvas.context.show_text(texto)
         self.canvas.context.fill()
+
         if self.actualiza_automaticamente:
             self.actualizar_imagen()
 
+    def obtener_area_de_texto(self, texto, tamano=32, fuente="sans"):
+        """Retorna el tamano que tendra el texto una vez dibujado.
+        
+        El resultado es una tupla de tipo (ancho, alto)."""
+        self.canvas.context.set_font_size(tamano)
+        self.canvas.context.select_font_face(fuente)
+        (_, _, ancho, alto, _, _) = self.canvas.context.text_extents(texto)
+        return (ancho, alto)
+    
+    def obtener_area_para_lista_de_texto(self, lista, tamano=32, fuente="sans"):
+        "Retorna el tamano que tendra una lista de cadenas de texto una vez dibujadas"
+        ancho = 0
+        alto = 0
+        
+        for opcion in lista:
+            ancho_opcion, alto_opcion = self.obtener_area_de_texto(opcion, tamano=14, fuente=fuente)
+            ancho = max(ancho, ancho_opcion)
+            alto += alto_opcion + 10
+    
+        return ancho, alto
+
     def dibujar_rectangulo(self, x, y, ancho, alto, pintar=True):
         self.canvas.context.rectangle(x, y, ancho, alto)
 
@@ -175,7 +201,53 @@ class Pizarra(Actor):
         
         self.canvas.context.close_path()
         self.canvas.context.stroke()
+        
+        if self.actualiza_automaticamente:
+            self.actualizar_imagen()
 
-        self.actualizar_imagen()
+    def pintar_cruz(self, x, y, ancho, color):
+        self.definir_color(color)
+        r = ancho
+        self.dibujar_poligono([(x-r, y+r), (x+r,y-r)])
+        self.dibujar_poligono([(x-r, y-r), (x+r,y+r)])
+        
+    def limpiar(self):
+        self.canvas.limpiar()
+        
+        if self.actualiza_automaticamente:
+            self.actualizar_imagen()
+            
+            
+    def dibujar_circulo(self, x, y, radio, pintar=True):
+        (x, y) = pilas.utils.hacer_coordenada_mundo(x, y)
+        
+        self.canvas.context.arc(x, y, radio, 0, 2*3.1415)
+        
+        if pintar:
+            self.canvas.context.fill()
+        else:
+            self.canvas.context.stroke()
+            
+            
+        if self.actualiza_automaticamente:
+            self.actualizar_imagen()
+            
+            
+class Pizarra(Actor, PizarraAbstracta):
+    """Representa una superficie de dibujo inicialmente transparente.
 
+    Puedes pintar sobre esta pizarra usando métodos que simulan
+    un lapiz, que se puede mover sobre una superficie.
+    """
 
+    def __init__(self, x=0, y=0):
+        Actor.__init__(self, x=x, y=y)
+        PizarraAbstracta.__init__(self)
+        
+    def definir_color(self, color):
+        PizarraAbstracta.definir_color(self, color)
+        
+    def actualizar_imagen(self):
+        "Se encarga de actualizar la vista de la pizarra."
+        self.canvas.actualizar()
+        self.definir_imagen(self.canvas.image)
\ No newline at end of file
