@@ -20,7 +20,7 @@ class Piezas(pilas.escenas.Normal):
     def __init__(self, ruta_a_la_imagen="ejemplos/data/piezas.png", filas=4, columnas=4):
         pilas.actores.utils.eliminar_a_todos()
         pilas.escenas.Normal.__init__(self, pilas.colores.grisoscuro)
-        grilla = pilas.imagenes.Grilla(ruta_a_la_imagen, columnas, filas)
+        grilla = pilas.imagenes.cargar_grilla(ruta_a_la_imagen, columnas, filas)
         self.crear_piezas(grilla, filas, columnas)
         self.pieza_en_movimiento = None
 
