@@ -12,11 +12,30 @@ mueve_mouse = dispatch.Signal(providing_args=['x', 'y', 'dx', 'dy'])
 click_de_mouse = dispatch.Signal(providing_args=['button', 'x', 'y'])
 termina_click = dispatch.Signal(providing_args=['button', 'x', 'y'])
 mueve_rueda = dispatch.Signal(providing_args=['delta'])
-pulsa_tecla = dispatch.Signal(providing_args=['code'])
+pulsa_tecla = dispatch.Signal(providing_args=['codigo'])
 pulsa_tecla_escape = dispatch.Signal(providing_args=[])
 actualizar = dispatch.Signal(providing_args=[])
+post_dibujar = dispatch.Signal(providing_args=[])
 
 # Se emite cuando el mundo ingresa o sale del modo depuracion (pulsando F12)
 inicia_modo_depuracion = dispatch.Signal(providing_args=[]) 
 sale_modo_depuracion = dispatch.Signal(providing_args=[])
 actualiza_modo_depuracion = dispatch.Signal(providing_args=[])
+
+
+def imprimir_todos():
+    "Muestra en consola los eventos activos y a quienes invocan"
+    imprime_alguno = False
+    
+    for x in globals().items():
+        nombre = x[0]
+        evento = x[1]
+        
+        if isinstance(evento, dispatch.Signal):
+            if evento.esta_conectado():
+                imprime_alguno = True
+                print "%s:" %(nombre)
+                evento.imprimir_funciones_conectadas()
+                
+    if not imprime_alguno:
+        print "Ningun evento esta conectado."
\ No newline at end of file
