@@ -129,3 +129,15 @@ def interpolable(f):
 
 def hacer_coordenada_mundo(x, y):
     return (x + 320, 240 - y)
+
+
+def listar_actores_en_consola():
+    todos = pilas.actores.todos
+    
+    print "Hay %d actores en la escena:" %(len(todos))
+    print ""
+
+    for s in todos:
+        print "\t", s
+
+    print ""
\ No newline at end of file
